package jugs.javafx.d_charts;

import javafx.animation.RotateTransition;
import javafx.animation.TranslateTransition;
import javafx.application.Application;
import javafx.collections.FXCollections;
import javafx.collections.ObservableList;
import javafx.scene.Scene;
import javafx.scene.chart.PieChart;
import javafx.scene.layout.StackPane;
import javafx.stage.Stage;
import javafx.util.Duration;

/**
 * Beispielprogramm für JavaFX-Schulung 
 * 
 * @author Michael Inden
 * 
 * Copyright 2015 by Michael Inden 
 */
public class PieChartExampleWithRotation extends Application
{
    public static void main(String[] args)
    {
        Application.launch(args);
    }

    @Override
    public void start(final Stage initialStage) throws Exception
    {
        initialStage.setTitle("PieChartExample");

        final PieChart pieChart = new PieChart();
        pieChart.setData(getPieChartData());

        final StackPane container = new StackPane();
        container.getChildren().add(pieChart);

        initialStage.setScene(new Scene(container, 500, 400));
        initialStage.show();

        createAnimations(pieChart);
    }

    protected void createAnimations(final PieChart pieChart)
    {
        final TranslateTransition translateTransition = new TranslateTransition(Duration.millis(2500));
        translateTransition.setNode(pieChart);
        translateTransition.setFromX(0);
        translateTransition.setToX(-50);
        translateTransition.setFromY(0);
        translateTransition.setToY(-200);
        translateTransition.setCycleCount(4);
        translateTransition.setAutoReverse(true);
        translateTransition.playFromStart();

        final RotateTransition rotateTransition = new RotateTransition(Duration.millis(10_000));
        rotateTransition.setNode(pieChart);
        rotateTransition.setByAngle(360);
        rotateTransition.setAutoReverse(true);
        rotateTransition.playFromStart();
    }

    public static ObservableList<PieChart.Data> getPieChartData()
    {
        final ObservableList<PieChart.Data> pieChartData = FXCollections.observableArrayList();

        pieChartData.add(new PieChart.Data("JavaFX", 24.0));
        pieChartData.add(new PieChart.Data("Swing", 54.0));
        pieChartData.add(new PieChart.Data("AWT", 5.0));
        pieChartData.add(new PieChart.Data("GWT", 6.0));
        pieChartData.add(new PieChart.Data("SWT", 11.0));

        return pieChartData;
    }
}
