package jugs.javafx.zusatz3_datamodelling;

import java.time.LocalDate;
import java.util.ArrayList;
import java.util.List;

import javafx.beans.property.ObjectProperty;
import javafx.beans.property.SimpleObjectProperty;
import javafx.beans.property.SimpleStringProperty;

/**
 * Beispielprogramm für JavaFX-Schulung 
 * 
 * @author Michael Inden
 * 
 * Copyright 2015 by Michael Inden 
 */
public class MemoryConsumptionPropertyBasedDataModel
{
    enum Mode {
        POJO, PROPERTY_BASED
    };

    public static void main(String[] args)
    {
        createEmployese(Mode.PROPERTY_BASED); // Used: 3.217.649.688 B => 321,7649688 B / Objekt
        //createEmployese(Mode.POJO); // Used: 1.987.266.576 B => 198 Bytes pro Objekt
    }

    private static void createEmployese(final Mode creationMode)
    {
        final List<Employee> employees = new ArrayList<>();
        //final List<Employee> employees = new ArrayList<>(10_000_000);

        for (int i = 0; i < 10_000_000; i++)
        {
            employees.add(createNewEmployee(creationMode));
            if (i % 1_000_000 == 0)
                System.out.println("1 Million");
        }

        System.out.println(employees.size());
    }

    private static int count = 0;

    private static Employee createNewEmployee(final Mode creationMode)
    {
        if (creationMode == Mode.POJO)
            return new PojoEmployee("Mike" + count++, "Department " + (count % 10), LocalDate.now());

        return new PropertyEmployee("Mike" + count++, "Department " + (count % 10), LocalDate.now());

    }

    public static class Employee
    {

    }

    public static class PropertyEmployee extends Employee
    {

        private final SimpleStringProperty      name;

        private final SimpleStringProperty      department;

        private final ObjectProperty<LocalDate> birthday;

        public PropertyEmployee(String name, String department, LocalDate birthday)
        {
            this.name = new SimpleStringProperty(name);
            this.department = new SimpleStringProperty(department);
            this.birthday = new SimpleObjectProperty<LocalDate>(birthday);
        }

        public LocalDate getBirthday()
        {
            return birthday.get();
        }

        public String getName()
        {
            return name.get();
        }

        public void setName(String fName)
        {
            name.set(fName);
        }

        public String getDepartment()
        {
            return department.get();
        }

        public void setDepartment(String fName)
        {
            department.set(fName);
        }
    }

    public static class PojoEmployee extends Employee
    {

        private String          name;

        private String          department;

        private final LocalDate birthday;

        public PojoEmployee(String name, String department, LocalDate birthday)
        {
            this.name = name;
            this.department = department;
            this.birthday = birthday;
        }

        public LocalDate getBirthday()
        {
            return birthday;
        }

        public String getName()
        {
            return name;
        }

        public void setName(String fName)
        {
            name = fName;
        }

        public String getDepartment()
        {
            return department;
        }

        public void setDepartment(String fName)
        {
            department = fName;
        }
    }
}
